@@ -99,7 +99,9 @@ def diarize_and_split_audio(
 
     # Load pipeline
     if diarization_pipeline is None:
-        diarization_pipeline = Pipeline.from_pretrained("pyannote/speaker-diarization")
+        diarization_pipeline = Pipeline.from_pretrained(
+            "pyannote/speaker-diarization",
+        )
 
     # Diarize
     dia = diarization_pipeline(audio_file)
@@ -512,8 +514,8 @@ def prepare_dataset(
         if iters == n_iterations:
             raise ValueError(
                 f"Could not find train, test, and validation sets that meet the "
-                f"holdout and stratification criteria after {n_iterations}. "
-                f"Recommended to annotate more data."
+                f"holdout and stratification criteria after {n_iterations} "
+                f"sampling iterations. Recommended to annotate more data."
             )
         log.debug(f"Attempted train test validation split construction {iters} times.")
 
